//******************************************************************************
//  ES437 Jenny Demo
//
//	by
//  Troy Harstad
//  SoftBaugh, Inc.
//  June 2004
//  Built with IAR Embedded Workbench V2
//******************************************************************************

#include "msp430x43x.h"

#define LCD_DIV_32	0x00
#define LCD_DIV_64	0x08
#define LCD_DIV_128	0x10
#define LCD_DIV_256	0x18

void InitializeHardware( void );
void DisplayAccessories( void );

int m_nAccessoryState = 0;

void main( void )
{	
    WDTCTL = WDTPW + WDTHOLD;             // Stop WDT

	InitializeHardware();

	_EINT();    // Enable interrupts

	for (;;)                              
	{
		// Toggle P1.0
		P1OUT ^= 0x01;

	    _BIS_SR(LPM3_bits);                 // Enter LPM3
		_NOP();                             // Required only for C-spy

		DisplayAccessories();
	}
}

void DisplayAccessories( void )
{
	switch( m_nAccessoryState )
	{	case 0:
			LCDM8 = 0x12;	// S15:S14
			LCDM9 = 0x81;	// S17:S16
			LCDM10 = 0x9F;	// S19:S18
			LCDM11 = 0x10;	// S21:S20
			
			break;

		case 1:
			LCDM8 = 0x12;	// S15:S14
			LCDM9 = 0x81;	// S17:S16
			LCDM10 = 0xDF;	// S19:S18
			LCDM11 = 0x20;	// S21:S20
			break;

		case 2:
			LCDM8 = 0x22;	// S15:S14
			LCDM9 = 0x13;	// S17:S16
			LCDM10 = 0xDF;	// S19:S18
			LCDM11 = 0x24;	// S21:S20
			break;

		case 3:
			LCDM8 = 0x22;	// S15:S14
			LCDM9 = 0x13;	// S17:S16
			LCDM10 = 0xFD;	// S19:S18
			LCDM11 = 0x24;	// S21:S20
			break;

		case 4:
			LCDM8 = 0x42;	// S15:S14
			LCDM9 = 0x17;	// S17:S16
			LCDM10 = 0xFD;	// S19:S18
			LCDM11 = 0x46;	// S21:S20
			break;
	
		case 5:
			LCDM8 = 0x42;	// S15:S14
			LCDM9 = 0x27;	// S17:S16
			LCDM10 = 0xFD;	// S19:S18
			LCDM11 = 0x46;	// S21:S20
			break;

		case 6:
			LCDM8 = 0x82;	// S15:S14
			LCDM9 = 0x2F;	// S17:S16
			LCDM10 = 0x0D;	// S19:S18
			LCDM11 = 0x47;	// S21:S20
			break;

		case 7:
			LCDM8 = 0x82;	// S15:S14
			LCDM9 = 0x2F;	// S17:S16
			LCDM10 = 0x09;	// S19:S18
			LCDM11 = 0x83;	// S21:S20
			break;

		case 8:
			LCDM8 = 0x0B;	// S15:S14
			LCDM9 = 0x4F;	// S17:S16
			LCDM10 = 0x19;	// S19:S18
			LCDM11 = 0x83;	// S21:S20
			break;

		case 9:
			LCDM8 = 0x0B;	// S15:S14
			LCDM9 = 0x4F;	// S17:S16
			LCDM10 = 0x99;	// S19:S18
			LCDM11 = 0x81;	// S21:S20
			break;

		case 10:
			LCDM8 = 0x0E;	// S15:S14
			LCDM9 = 0x4F;	// S17:S16
			LCDM10 = 0x90;	// S19:S18
			LCDM11 = 0x11;	// S21:S20
			break;

		case 11:
			LCDM8 = 0x0E;	// S15:S14
			LCDM9 = 0x8F;	// S17:S16
			LCDM10 = 0xD0;	// S19:S18
			LCDM11 = 0x11;	// S21:S20
			break;

		default:
			m_nAccessoryState = 0;
	}
	
	m_nAccessoryState++;
	if( m_nAccessoryState >= 12 )
	{	m_nAccessoryState = 0;
	}
}

void InitializeHardware( void )
{int i;

	FLL_CTL0 |= XCAP10PF;       // Set load capacitance for xtal
                                    //and
        i = 10000;                  // Delay for clock stabilization
        do (i--);
        while (i != 0);
	
	// Setup Basic Timer for LCD operation
	BTCTL = (LCD_DIV_64+0x23);

	// Turn on Basic Timer interrupts
	IE2 |= BTIE;

	// Setup port functions
	P1DIR = 0x33;
	P1SEL = 0x32;

	P2SEL = 0xC0;
	P2DIR = 0xC0;



	P4SEL = 0x3F;
	P4DIR = 0xFF;
	
	P5SEL = 0xFF;
	P5DIR = 0xFF;
	
	// Setup LCD
	LCDCTL = (LCDSG0_3|LCD4MUX|LCDSON|LCDON);
	// Setup LCD data
	LCDM1 = 0x37;	// S1:S0	
	LCDM2 = 0x5F;	// S3:S2
	LCDM3 = 0x2F;	// S5:S4
	LCDM4 = 0x3D;	// S7:S6
	LCDM5 = 0x07;	// S9:S8
	LCDM6 = 0x7C;	// S11:S10
	LCDM7 = 0x7F;	// S13:S12
	LCDM8 = 0xFF;	// S15:S14
	LCDM9 = 0xFF;	// S17:S16
	LCDM10 = 0xFF;	// S19:S18
	LCDM11 = 0xFF;	// S21:S20
}
// Basic Timer interrupt service routine
#pragma vector=BASICTIMER_VECTOR
__interrupt void basic_timer (void)
{
	_BIC_SR_IRQ(LPM3_bits);
}



